import 'package:flutter/material.dart';
import 'package:reactive_dropdown_field/reactive_dropdown_field.dart';
import 'package:reactive_forms/reactive_forms.dart' hide ReactiveDropdownField;

void main() {
  runApp(const MyApp());
}

class MyApp extends StatelessWidget {
  const MyApp({Key? key}) : super(key: key);

  FormGroup buildForm() => fb.group({
        'input': FormControl<bool>(value: null),
      });

  @override
  Widget build(BuildContext context) {
    return MaterialApp(
      theme: ThemeData(
        primarySwatch: Colors.blue,
        visualDensity: VisualDensity.adaptivePlatformDensity,
      ),
      home: Scaffold(
        appBar: AppBar(),
        body: SafeArea(
          child: SingleChildScrollView(
            physics: const BouncingScrollPhysics(),
            padding: const EdgeInsets.symmetric(
              horizontal: 20.0,
              vertical: 20.0,
            ),
            child: ReactiveFormBuilder(
              form: buildForm,
              builder: (context, form, child) {
                return Column(
                  children: [
                    ReactiveDropdownField<bool, bool>(
                      formControlName: 'input',
                      decoration: const InputDecoration(
                        labelText: 'Want to stay logged in?',
                      ),
                      items: const [
                        DropdownMenuItem<bool>(value: true, child: Text('Yes')),
                        DropdownMenuItem<bool>(value: false, child: Text('No')),
                      ],
                    ),
                    const SizedBox(height: 16),
                    ElevatedButton(
                      child: const Text('Sign Up'),
                      onPressed: () {
                        if (form.valid) {
                          print(form.value);
                        } else {
                          form.markAllAsTouched();
                        }
                      },
                    ),
                  ],
                );
              },
            ),
          ),
        ),
      ),
    );
  }
}
